@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 use base 'Text::Pipe::Base';
@@ -55,6 +55,64 @@ Text::Pipe::Multiplex - Common text filter API
 
 Text::Pipe::Multiplex inherits from L<Text::Pipe::Base>.
 
+The superclass L<Text::Pipe::Base> defines these methods and functions:
+
+    new(), ()(), (|(), bit_or(), filter_single(), init()
+
+The superclass L<Class::Accessor::Complex> defines these methods and
+functions:
+
+    carp(), cluck(), croak(), flatten(), mk_abstract_accessors(),
+    mk_array_accessors(), mk_boolean_accessors(),
+    mk_class_array_accessors(), mk_class_hash_accessors(),
+    mk_class_scalar_accessors(), mk_concat_accessors(),
+    mk_forward_accessors(), mk_hash_accessors(), mk_integer_accessors(),
+    mk_new(), mk_object_accessors(), mk_scalar_accessors(),
+    mk_set_accessors(), mk_singleton()
+
+The superclass L<Class::Accessor> defines these methods and functions:
+
+    _carp(), _croak(), _mk_accessors(), accessor_name_for(),
+    best_practice_accessor_name_for(), best_practice_mutator_name_for(),
+    follow_best_practice(), get(), make_accessor(), make_ro_accessor(),
+    make_wo_accessor(), mk_accessors(), mk_ro_accessors(),
+    mk_wo_accessors(), mutator_name_for(), set()
+
+The superclass L<Class::Accessor::Installer> defines these methods and
+functions:
+
+    install_accessor(), subname()
+
+The superclass L<Class::Accessor::Constructor> defines these methods and
+functions:
+
+    NO_DIRTY(), WITH_DIRTY(), _make_constructor(), mk_constructor(),
+    mk_constructor_with_dirty(), mk_singleton_constructor()
+
+The superclass L<Data::Inherited> defines these methods and functions:
+
+    every_hash(), every_list(), flush_every_cache_by_key()
+
+The superclass L<Class::Accessor::Constructor::Base> defines these methods
+and functions:
+
+    HYGIENIC(), STORE(), clear_dirty(), clear_hygienic(),
+    clear_unhygienic(), contains_hygienic(), contains_unhygienic(),
+    delete_hygienic(), delete_unhygienic(), dirty(), dirty_clear(),
+    dirty_set(), elements_hygienic(), elements_unhygienic(), hygienic(),
+    hygienic_clear(), hygienic_contains(), hygienic_delete(),
+    hygienic_elements(), hygienic_insert(), hygienic_is_empty(),
+    hygienic_size(), insert_hygienic(), insert_unhygienic(),
+    is_empty_hygienic(), is_empty_unhygienic(), set_dirty(),
+    size_hygienic(), size_unhygienic(), unhygienic(), unhygienic_clear(),
+    unhygienic_contains(), unhygienic_delete(), unhygienic_elements(),
+    unhygienic_insert(), unhygienic_is_empty(), unhygienic_size()
+
+The superclass L<Tie::StdHash> defines these methods and functions:
+
+    CLEAR(), DELETE(), EXISTS(), FETCH(), FIRSTKEY(), NEXTKEY(), SCALAR(),
+    TIEHASH()
+
 =head1 METHODS
 
 =over 4
@@ -228,6 +286,10 @@ Unshifts elements onto the beginning of the array.
 If you talk about this module in blogs, on del.icio.us or anywhere else,
 please use the C<textpipe> tag.
 
+=head1 VERSION 
+                   
+This document describes version 0.05 of L<Text::Pipe::Multiplex>.
+
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
